OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bókamerki",
    "No file provided for import" : "Engin skrá valin til innflutnings",
    "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
    "Bookmarks shared by %s" : "Bókamerki deilt af %s",
    "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
    "Select bookmark" : "Veldu bókamerki",
    "Details" : "Nánar",
    "Rename" : "Endurnefna",
    "Move" : "Færa",
    "Delete" : "Eyða",
    "Open all selected" : "Opna allt valið",
    "Move selection" : "Færa valið",
    "Delete selection" : "Eyða vali",
    "Select all" : "Select all",
    "Cancel selection" : "Hætta við val",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
    "Select one or more tags" : "Veldu eitt eða fleiri merki",
    "New" : "Nýtt",
    "New bookmark" : "Nýtt bókamerki",
    "New folder" : "Ný mappa",
    "RSS feed copied" : "RSS-fréttastreymi afritað",
    "Enter a link" : "Settu inn slóð",
    "Select folder" : "Veldu möppu",
    "Enter folder title" : "Settu inn heiti möppu",
    "Shared by {user}" : "Deilt af {user}",
    "Submit" : "Senda inn",
    "Cancel" : "Hætta við",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
    "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
    "All bookmarks" : "Öll bókamerki",
    "Recent" : "Nýlegt",
    "Untagged" : "Ómerkt",
    "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
    "No bookmarks here" : "Engin bókamerki hér",
    "Import" : "Flytja inn",
    "Export" : "Flytja út",
    "Client apps" : "Biðlaraforrit",
    "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
    "Bookmarklet" : "Bókamerklingur",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dragðu þetta yfir í bókamerkin í vafranum þínu og smelltu, ef þú vilt bæta við bókamerki fyrir þessa vefsíðu á fljótlegan hátt",
    "Add to {instanceName}" : "Bæta við {instanceName}",
    "Clear data" : "Hreinsa gögn",
    "Delete all bookmarks" : "Eyða öllum bókamerkjum",
    "Do you really want to delete all your bookmarks?" : "Viltu í alvörunni eyða öllum bókmerkjunum þínum?",
    "Title" : "Titill",
    "Link" : "Tengill",
    "Tags" : "Merki",
    "Notes" : "Minnispunktar",
    "Owner" : "Eigandi",
    "Sharing" : "Deiling",
    "Select a user or group" : "Veldu notanda eða hóp",
    "Share link" : "Deila tengli",
    "Copy link" : "Afrita tengil",
    "Copy RSS feed" : "Afrita RSS-fréttastreymi",
    "Delete link" : "Eyða tengli",
    "Create public link" : "Búa til opinberan tengil",
    "Allow editing" : "Leyfa breytingar",
    "Remove share" : "Fjarlægja sameign",
    "Link copied" : "Tengill afritaður",
    "Privacy" : "Gagnaleynd",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
    "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
    "Performance" : "Afköst",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
    "Previews" : "Forskoðun",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
    "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
    "Screeenly API key" : "Screeenly API-lykill",
    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
    "Failed to save settings" : "Mistókst að vista stillingar",
    "Add a bookmark" : "Bæta við bókamerki",
    "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
    "Enter bookmark title" : "Settu inn titil á bókamerki",
    "Enter bookmark URL" : "Settu inn slóð á bókamerki",
    "Folder" : "Mappa",
    "Root Folder" : "Rótarmappa",
    "Save" : "Vista",
    "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
    "Failed to create bookmark" : "Mistókst að búa til bókamerki",
    "Failed to save bookmark" : "Mistókst að vista bókamerki",
    "Failed to move bookmark" : "Mistókst að færa bókamerki",
    "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
    "Failed to load tags" : "Mistókst að hlaða inn merkjum",
    "Failed to load folders" : "Mistókst að hlaða inn möppum",
    "Failed to delete folder" : "Mistókst að eyða möppu",
    "Failed to create folder" : "Mistókst að búa til möppu",
    "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
    "Failed to change setting" : "Mistókst að breyta stillingu",
    "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
    "Failed to update share {shareId}" : "Mistókst að uppfæra sameignina {shareId}",
    "Failed to delete share {shareId}" : "Mistókst að eyða sameigninni {shareId}",
    "Bookmarks feed" : "Bókamerkjastreymi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
